ConfigServiceV2 class final

Service for configuring sinks used to route log entries.

Implementers

Constructors

ConfigServiceV2({required Client client, Uri? endPoint, String? gcclVersion})
Creates a ConfigServiceV2 using client for transport.
ConfigServiceV2.fromApiKey([String? apiKey])
Creates a ConfigServiceV2 that does authentication through an API key.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelOperation(CancelOperationRequest request) → Future<void>
Provides the Operations service functionality in this service.
close() → void
Closes the client and cleans up any resources associated with it.
copyLogEntries(CopyLogEntriesRequest request) → Future<Operation<CopyLogEntriesResponse, CopyLogEntriesMetadata>>
Copies a set of log entries from a log bucket to a Cloud Storage bucket.
createBucket(CreateBucketRequest request) → Future<LogBucket>
Creates a log bucket that can be used to store log entries. After a bucket has been created, the bucket's location cannot be changed.
createBucketAsync(CreateBucketRequest request) → Future<Operation<LogBucket, BucketMetadata>>
Creates a log bucket asynchronously that can be used to store log entries.
createExclusion(CreateExclusionRequest request) → Future<LogExclusion>
Creates a new exclusion in the _Default sink in a specified parent resource. Only log entries belonging to that resource can be excluded. You can have up to 10 exclusions in a resource.
Asynchronously creates a linked dataset in BigQuery which makes it possible to use BigQuery to read the logs stored in the log bucket. A log bucket may currently only contain one link.
createSink(CreateSinkRequest request) → Future<LogSink>
Creates a sink that exports specified log entries to a destination. The export of newly-ingested log entries begins immediately, unless the sink's writer_identity is not permitted to write to the destination. A sink can export log entries only from the resource owning the sink.
createView(CreateViewRequest request) → Future<LogView>
Creates a view over log entries in a log bucket. A bucket may contain a maximum of 30 views.
deleteBucket(DeleteBucketRequest request) → Future<void>
Deletes a log bucket.
deleteExclusion(DeleteExclusionRequest request) → Future<void>
Deletes an exclusion in the _Default sink.
Deletes a link. This will also delete the corresponding BigQuery linked dataset.
deleteSink(DeleteSinkRequest request) → Future<void>
Deletes a sink. If the sink has a unique writer_identity, then that service account is also deleted.
deleteView(DeleteViewRequest request) → Future<void>
Deletes a view on a log bucket. If an UNAVAILABLE error is returned, this indicates that system is not in a state where it can delete the view. If this occurs, please try again in a few minutes.
getBucket(GetBucketRequest request) → Future<LogBucket>
Gets a log bucket.
getCmekSettings(GetCmekSettingsRequest request) → Future<CmekSettings>
Gets the Logging CMEK settings for the given resource.
getExclusion(GetExclusionRequest request) → Future<LogExclusion>
Gets the description of an exclusion in the _Default sink.
Gets a link.
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) → Future<Operation<T, S>>
Provides the Operations service functionality in this service.
getSettings(GetSettingsRequest request) → Future<Settings>
Gets the Log Router settings for the given resource.
getSink(GetSinkRequest request) → Future<LogSink>
Gets a sink.
getView(GetViewRequest request) → Future<LogView>
Gets a view on a log bucket..
listBuckets(ListBucketsRequest request) → Future<ListBucketsResponse>
Lists log buckets.
listExclusions(ListExclusionsRequest request) → Future<ListExclusionsResponse>
Lists all the exclusions on the _Default sink in a parent resource.
Lists links.
listOperations(ListOperationsRequest request) → Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
listSinks(ListSinksRequest request) → Future<ListSinksResponse>
Lists sinks.
listViews(ListViewsRequest request) → Future<ListViewsResponse>
Lists views on a log bucket.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
undeleteBucket(UndeleteBucketRequest request) → Future<void>
Undeletes a log bucket. A bucket that has been deleted can be undeleted within the grace period of 7 days.
updateBucket(UpdateBucketRequest request) → Future<LogBucket>
Updates a log bucket.
updateBucketAsync(UpdateBucketRequest request) → Future<Operation<LogBucket, BucketMetadata>>
Updates a log bucket asynchronously.
updateCmekSettings(UpdateCmekSettingsRequest request) → Future<CmekSettings>
Updates the Log Router CMEK settings for the given resource.
updateExclusion(UpdateExclusionRequest request) → Future<LogExclusion>
Changes one or more properties of an existing exclusion in the _Default sink.
updateSettings(UpdateSettingsRequest request) → Future<Settings>
Updates the Log Router settings for the given resource.
updateSink(UpdateSinkRequest request) → Future<LogSink>
Updates a sink. This method replaces the following fields in the existing sink with values from the new sink: destination, and filter.
updateView(UpdateViewRequest request) → Future<LogView>
Updates a view on a log bucket. This method replaces the following fields in the existing view with values from the new view: filter. If an UNAVAILABLE error is returned, this indicates that system is not in a state where it can update the view. If this occurs, please try again in a few minutes.

Operators

operator ==(Object other) → bool
The equality operator.
inherited