updateExclusion method

Future<LogExclusion> updateExclusion(
  1. UpdateExclusionRequest request
)

Changes one or more properties of an existing exclusion in the _Default sink.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<LogExclusion> updateExclusion(UpdateExclusionRequest request) async {
  final url = _endPoint.replace(
    path: '/v2/${request.name}',
    queryParameters: {
      if (request.updateMask case final $1?) 'updateMask': $1.toJson(),
    },
  );
  final response = await _client.patch(url, body: request.exclusion);
  return LogExclusion.fromJson(response);
}