IndexConfig class final

Configuration for an indexed field.

Constructors

IndexConfig({required String fieldPath, required IndexType type, Timestamp? createTime})
IndexConfig.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. The timestamp when the index was last modified.
final
fieldPath → String
Required. The LogEntry field path to index.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → IndexType
Required. The type of data in this index.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String