LifecycleState class final

LogBucket lifecycle states.

Constructors

LifecycleState(String value)
const
LifecycleState.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const LifecycleState
The default value for LifecycleState.
active → const LifecycleState
The normal and active state.
creating → const LifecycleState
The resource has been marked for creation by the user. It will remain in this state until the creation is complete.
deleteRequested → const LifecycleState
The resource has been marked for deletion by the user. For some resources (e.g. buckets), this can be reversed by an un-delete operation.
failed → const LifecycleState
The resource is in an INTERNAL error state.
lifecycleStateUnspecified → const LifecycleState
Unspecified state. This is only used/useful for distinguishing unset values.
updating → const LifecycleState
The resource has been marked for an update by the user. It will remain in this state until the update is complete.