LinkMetadata class final

Metadata for long running Link operations.

Constructors

LinkMetadata({Timestamp? startTime, Timestamp? endTime, OperationState state = OperationState.$default, CreateLinkRequest? createLinkRequest, DeleteLinkRequest? deleteLinkRequest})
LinkMetadata.fromJson(Object? j)
factory

Properties

createLinkRequest → CreateLinkRequest?
CreateLink RPC request.
final
deleteLinkRequest → DeleteLinkRequest?
DeleteLink RPC request.
final
endTime → Timestamp?
The end time of an operation.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → Timestamp?
The start time of an operation.
final
state → OperationState
State of an operation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String