LogBucket class final

Describes a repository in which log entries are stored.

Constructors

LogBucket({String name = '', String description = '', Timestamp? createTime, Timestamp? updateTime, int retentionDays = 0, bool locked = false, LifecycleState lifecycleState = LifecycleState.$default, bool analyticsEnabled = false, List<String> restrictedFields = const [], List<IndexConfig> indexConfigs = const [], CmekSettings? cmekSettings})
LogBucket.fromJson(Object? j)
factory

Properties

analyticsEnabled → bool
Whether log analytics is enabled for this bucket.
final
cmekSettings → CmekSettings?
The CMEK settings of the log bucket. If present, new log entries written to this log bucket are encrypted using the CMEK key provided in this configuration. If a log bucket has CMEK settings, the CMEK settings cannot be disabled later by updating the log bucket. Changing the KMS key is allowed.
final
createTime → Timestamp?
Output only. The creation timestamp of the bucket. This is not set for any of the default buckets.
final
description → String
Describes this bucket.
final
hashCode → int
The hash code for this object.
no setterinherited
indexConfigs → List<IndexConfig>
A list of indexed fields and related configuration data.
final
lifecycleState → LifecycleState
Output only. The bucket lifecycle state.
final
locked → bool
Whether the bucket is locked.
final
name → String
Output only. The resource name of the bucket.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
restrictedFields → List<String>
Log entry field paths that are denied access in this bucket.
final
retentionDays → int
Logs will be retained by default for this amount of time, after which they will automatically be deleted. The minimum retention period is 1 day. If this value is set to zero at bucket creation time, the default time of 30 days will be used.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime → Timestamp?
Output only. The last update timestamp of the bucket.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String