LogView class final

Describes a view over log entries in a bucket.

Constructors

LogView({String name = '', String description = '', Timestamp? createTime, Timestamp? updateTime, String filter = ''})
LogView.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. The creation timestamp of the view.
final
description → String
Describes this view.
final
filter → String
Filter that restricts which log entries in a bucket are visible in this view.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The resource name of the view.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime → Timestamp?
Output only. The last update timestamp of the view.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String