listLogs method

Future<ListLogsResponse> listLogs(
  1. ListLogsRequest request
)

Lists the logs in projects, organizations, folders, or billing accounts. Only logs that have entries are listed.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<ListLogsResponse> listLogs(ListLogsRequest request) async {
  final url = _endPoint.replace(
    path: '/v2/${request.parent}/logs',
    queryParameters: {
      if (request.resourceNames case final $1 when $1.isNotDefault)
        'resourceNames': $1,
      if (request.pageSize case final $1 when $1.isNotDefault)
        'pageSize': '${$1}',
      if (request.pageToken case final $1 when $1.isNotDefault)
        'pageToken': $1,
    },
  );
  final response = await _client.get(url);
  return ListLogsResponse.fromJson(response);
}