OperationState class final

List of different operation states. High level state of the operation. This is used to report the job's current state to the user. Once a long running operation is created, the current state of the operation can be queried even before the operation is finished and the final result is available.

Constructors

OperationState(String value)
const
OperationState.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const OperationState
The default value for OperationState.
operationStateCancelled → const OperationState
The operation was cancelled by the user.
operationStateFailed → const OperationState
The operation failed.
operationStateRunning → const OperationState
The operation is running.
operationStateScheduled → const OperationState
The operation is scheduled.
operationStateSucceeded → const OperationState
The operation was completed successfully.
operationStateUnspecified → const OperationState
Should not be used.
operationStateWaitingForPermissions → const OperationState
Waiting for necessary permissions.