FakeConfigServiceV2 class base

Testing fake for ConfigServiceV2.

Implemented types

Constructors

FakeConfigServiceV2({Future<ListBucketsResponse> listBuckets(ListBucketsRequest request)?, Future<LogBucket> getBucket(GetBucketRequest request)?, Future<Operation<LogBucket, BucketMetadata>> createBucketAsync(CreateBucketRequest request)?, Future<Operation<LogBucket, BucketMetadata>> updateBucketAsync(UpdateBucketRequest request)?, Future<LogBucket> createBucket(CreateBucketRequest request)?, Future<LogBucket> updateBucket(UpdateBucketRequest request)?, Future<void> deleteBucket(DeleteBucketRequest request)?, Future<void> undeleteBucket(UndeleteBucketRequest request)?, Future<ListViewsResponse> listViews(ListViewsRequest request)?, Future<LogView> getView(GetViewRequest request)?, Future<LogView> createView(CreateViewRequest request)?, Future<LogView> updateView(UpdateViewRequest request)?, Future<void> deleteView(DeleteViewRequest request)?, Future<ListSinksResponse> listSinks(ListSinksRequest request)?, Future<LogSink> getSink(GetSinkRequest request)?, Future<LogSink> createSink(CreateSinkRequest request)?, Future<LogSink> updateSink(UpdateSinkRequest request)?, Future<void> deleteSink(DeleteSinkRequest request)?, Future<Operation<Link, LinkMetadata>> createLink(CreateLinkRequest request)?, Future<Operation<Empty, LinkMetadata>> deleteLink(DeleteLinkRequest request)?, Future<ListLinksResponse> listLinks(ListLinksRequest request)?, Future<Link> getLink(GetLinkRequest request)?, Future<ListExclusionsResponse> listExclusions(ListExclusionsRequest request)?, Future<LogExclusion> getExclusion(GetExclusionRequest request)?, Future<LogExclusion> createExclusion(CreateExclusionRequest request)?, Future<LogExclusion> updateExclusion(UpdateExclusionRequest request)?, Future<void> deleteExclusion(DeleteExclusionRequest request)?, Future<CmekSettings> getCmekSettings(GetCmekSettingsRequest request)?, Future<CmekSettings> updateCmekSettings(UpdateCmekSettingsRequest request)?, Future<Settings> getSettings(GetSettingsRequest request)?, Future<Settings> updateSettings(UpdateSettingsRequest request)?, Future<Operation<CopyLogEntriesResponse, CopyLogEntriesMetadata>> copyLogEntries(CopyLogEntriesRequest request)?, Future<ListOperationsResponse> listOperations(ListOperationsRequest request)?, Future<Operation<T, S>> getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request)?, Future<void> cancelOperation(CancelOperationRequest request)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelOperation(CancelOperationRequest request) Future<void>
Provides the Operations service functionality in this service.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
copyLogEntries(CopyLogEntriesRequest request) Future<Operation<CopyLogEntriesResponse, CopyLogEntriesMetadata>>
Copies a set of log entries from a log bucket to a Cloud Storage bucket.
override
createBucket(CreateBucketRequest request) Future<LogBucket>
Creates a log bucket that can be used to store log entries. After a bucket has been created, the bucket's location cannot be changed.
override
createBucketAsync(CreateBucketRequest request) Future<Operation<LogBucket, BucketMetadata>>
Creates a log bucket asynchronously that can be used to store log entries.
override
createExclusion(CreateExclusionRequest request) Future<LogExclusion>
Creates a new exclusion in the _Default sink in a specified parent resource. Only log entries belonging to that resource can be excluded. You can have up to 10 exclusions in a resource.
override
Asynchronously creates a linked dataset in BigQuery which makes it possible to use BigQuery to read the logs stored in the log bucket. A log bucket may currently only contain one link.
override
createSink(CreateSinkRequest request) Future<LogSink>
Creates a sink that exports specified log entries to a destination. The export of newly-ingested log entries begins immediately, unless the sink's writer_identity is not permitted to write to the destination. A sink can export log entries only from the resource owning the sink.
override
createView(CreateViewRequest request) Future<LogView>
Creates a view over log entries in a log bucket. A bucket may contain a maximum of 30 views.
override
deleteBucket(DeleteBucketRequest request) Future<void>
Deletes a log bucket.
override
deleteExclusion(DeleteExclusionRequest request) Future<void>
Deletes an exclusion in the _Default sink.
override
Deletes a link. This will also delete the corresponding BigQuery linked dataset.
override
deleteSink(DeleteSinkRequest request) Future<void>
Deletes a sink. If the sink has a unique writer_identity, then that service account is also deleted.
override
deleteView(DeleteViewRequest request) Future<void>
Deletes a view on a log bucket. If an UNAVAILABLE error is returned, this indicates that system is not in a state where it can delete the view. If this occurs, please try again in a few minutes.
override
getBucket(GetBucketRequest request) Future<LogBucket>
Gets a log bucket.
override
getCmekSettings(GetCmekSettingsRequest request) Future<CmekSettings>
Gets the Logging CMEK settings for the given resource.
override
getExclusion(GetExclusionRequest request) Future<LogExclusion>
Gets the description of an exclusion in the _Default sink.
override
Gets a link.
override
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) Future<Operation<T, S>>
Provides the Operations service functionality in this service.
override
getSettings(GetSettingsRequest request) Future<Settings>
Gets the Log Router settings for the given resource.
override
getSink(GetSinkRequest request) Future<LogSink>
Gets a sink.
override
getView(GetViewRequest request) Future<LogView>
Gets a view on a log bucket..
override
listBuckets(ListBucketsRequest request) Future<ListBucketsResponse>
Lists log buckets.
override
listExclusions(ListExclusionsRequest request) Future<ListExclusionsResponse>
Lists all the exclusions on the _Default sink in a parent resource.
override
Lists links.
override
listOperations(ListOperationsRequest request) Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
override
listSinks(ListSinksRequest request) Future<ListSinksResponse>
Lists sinks.
override
listViews(ListViewsRequest request) Future<ListViewsResponse>
Lists views on a log bucket.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
undeleteBucket(UndeleteBucketRequest request) Future<void>
Undeletes a log bucket. A bucket that has been deleted can be undeleted within the grace period of 7 days.
override
updateBucket(UpdateBucketRequest request) Future<LogBucket>
Updates a log bucket.
override
updateBucketAsync(UpdateBucketRequest request) Future<Operation<LogBucket, BucketMetadata>>
Updates a log bucket asynchronously.
override
updateCmekSettings(UpdateCmekSettingsRequest request) Future<CmekSettings>
Updates the Log Router CMEK settings for the given resource.
override
updateExclusion(UpdateExclusionRequest request) Future<LogExclusion>
Changes one or more properties of an existing exclusion in the _Default sink.
override
updateSettings(UpdateSettingsRequest request) Future<Settings>
Updates the Log Router settings for the given resource.
override
updateSink(UpdateSinkRequest request) Future<LogSink>
Updates a sink. This method replaces the following fields in the existing sink with values from the new sink: destination, and filter.
override
updateView(UpdateViewRequest request) Future<LogView>
Updates a view on a log bucket. This method replaces the following fields in the existing view with values from the new view: filter. If an UNAVAILABLE error is returned, this indicates that system is not in a state where it can update the view. If this occurs, please try again in a few minutes.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited