copyLogEntries method

  1. @override
Future<Operation<CopyLogEntriesResponse, CopyLogEntriesMetadata>> copyLogEntries(
  1. CopyLogEntriesRequest request
)
override

Copies a set of log entries from a log bucket to a Cloud Storage bucket.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<CopyLogEntriesResponse, CopyLogEntriesMetadata>>
copyLogEntries(CopyLogEntriesRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_copyLogEntries case final copyLogEntries?) {
    return copyLogEntries(request);
  }
  throw UnsupportedError('copyLogEntries');
}