createExclusion method

  1. @override
Future<LogExclusion> createExclusion(
  1. CreateExclusionRequest request
)
override

Creates a new exclusion in the _Default sink in a specified parent resource. Only log entries belonging to that resource can be excluded. You can have up to 10 exclusions in a resource.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<LogExclusion> createExclusion(CreateExclusionRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createExclusion case final createExclusion?) {
    return createExclusion(request);
  }
  throw UnsupportedError('createExclusion');
}