createLink method

  1. @override
Future<Operation<Link, LinkMetadata>> createLink(
  1. CreateLinkRequest request
)
override

Asynchronously creates a linked dataset in BigQuery which makes it possible to use BigQuery to read the logs stored in the log bucket. A log bucket may currently only contain one link.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<Link, LinkMetadata>> createLink(
  CreateLinkRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createLink case final createLink?) {
    return createLink(request);
  }
  throw UnsupportedError('createLink');
}