createView method

  1. @override
Future<LogView> createView(
  1. CreateViewRequest request
)
override

Creates a view over log entries in a log bucket. A bucket may contain a maximum of 30 views.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<LogView> createView(CreateViewRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createView case final createView?) {
    return createView(request);
  }
  throw UnsupportedError('createView');
}