deleteLink method

  1. @override
Future<Operation<Empty, LinkMetadata>> deleteLink(
  1. DeleteLinkRequest request
)
override

Deletes a link. This will also delete the corresponding BigQuery linked dataset.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<Empty, LinkMetadata>> deleteLink(
  DeleteLinkRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteLink case final deleteLink?) {
    return deleteLink(request);
  }
  throw UnsupportedError('deleteLink');
}