deleteView method

  1. @override
Future<void> deleteView(
  1. DeleteViewRequest request
)
override

Deletes a view on a log bucket. If an UNAVAILABLE error is returned, this indicates that system is not in a state where it can delete the view. If this occurs, please try again in a few minutes.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<void> deleteView(DeleteViewRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteView case final deleteView?) {
    return deleteView(request);
  }
  throw UnsupportedError('deleteView');
}