getCmekSettings method

  1. @override
Future<CmekSettings> getCmekSettings(
  1. GetCmekSettingsRequest request
)
override

Gets the Logging CMEK settings for the given resource.

Note: CMEK for the Log Router can be configured for Google Cloud projects, folders, organizations and billing accounts. Once configured for an organization, it applies to all projects and folders in the Google Cloud organization.

See Enabling CMEK for Log Router for more information.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<CmekSettings> getCmekSettings(GetCmekSettingsRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_getCmekSettings case final getCmekSettings?) {
    return getCmekSettings(request);
  }
  throw UnsupportedError('getCmekSettings');
}