getExclusion method

  1. @override
Future<LogExclusion> getExclusion(
  1. GetExclusionRequest request
)
override

Gets the description of an exclusion in the _Default sink.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<LogExclusion> getExclusion(GetExclusionRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_getExclusion case final getExclusion?) {
    return getExclusion(request);
  }
  throw UnsupportedError('getExclusion');
}