undeleteBucket method

  1. @override
Future<void> undeleteBucket(
  1. UndeleteBucketRequest request
)
override

Undeletes a log bucket. A bucket that has been deleted can be undeleted within the grace period of 7 days.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<void> undeleteBucket(UndeleteBucketRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_undeleteBucket case final undeleteBucket?) {
    return undeleteBucket(request);
  }
  throw UnsupportedError('undeleteBucket');
}