updateBucketAsync method

  1. @override
Future<Operation<LogBucket, BucketMetadata>> updateBucketAsync(
  1. UpdateBucketRequest request
)
override

Updates a log bucket asynchronously.

If the bucket has a lifecycle_state of DELETE_REQUESTED, then FAILED_PRECONDITION will be returned.

After a bucket has been created, the bucket's location cannot be changed.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<LogBucket, BucketMetadata>> updateBucketAsync(
  UpdateBucketRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updateBucketAsync case final updateBucketAsync?) {
    return updateBucketAsync(request);
  }
  throw UnsupportedError('updateBucketAsync');
}