updateExclusion method

  1. @override
Future<LogExclusion> updateExclusion(
  1. UpdateExclusionRequest request
)
override

Changes one or more properties of an existing exclusion in the _Default sink.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<LogExclusion> updateExclusion(UpdateExclusionRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updateExclusion case final updateExclusion?) {
    return updateExclusion(request);
  }
  throw UnsupportedError('updateExclusion');
}