updateSink method

  1. @override
Future<LogSink> updateSink(
  1. UpdateSinkRequest request
)
override

Updates a sink. This method replaces the following fields in the existing sink with values from the new sink: destination, and filter.

The updated sink might also have a new writer_identity; see the unique_writer_identity field.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<LogSink> updateSink(UpdateSinkRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updateSink case final updateSink?) {
    return updateSink(request);
  }
  throw UnsupportedError('updateSink');
}