updateView method

  1. @override
Future<LogView> updateView(
  1. UpdateViewRequest request
)
override

Updates a view on a log bucket. This method replaces the following fields in the existing view with values from the new view: filter. If an UNAVAILABLE error is returned, this indicates that system is not in a state where it can update the view. If this occurs, please try again in a few minutes.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<LogView> updateView(UpdateViewRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_updateView case final updateView?) {
    return updateView(request);
  }
  throw UnsupportedError('updateView');
}