FakeLoggingServiceV2 class base

Testing fake for LoggingServiceV2.

Implemented types

Constructors

FakeLoggingServiceV2({Future<void> deleteLog(DeleteLogRequest request)?, Future<WriteLogEntriesResponse> writeLogEntries(WriteLogEntriesRequest request)?, Future<ListLogEntriesResponse> listLogEntries(ListLogEntriesRequest request)?, Future<ListMonitoredResourceDescriptorsResponse> listMonitoredResourceDescriptors(ListMonitoredResourceDescriptorsRequest request)?, Future<ListLogsResponse> listLogs(ListLogsRequest request)?, Future<ListOperationsResponse> listOperations(ListOperationsRequest request)?, Future<Operation<T, S>> getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request)?, Future<void> cancelOperation(CancelOperationRequest request)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelOperation(CancelOperationRequest request) Future<void>
Provides the Operations service functionality in this service.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
deleteLog(DeleteLogRequest request) Future<void>
Deletes all the log entries in a log for the _Default Log Bucket. The log reappears if it receives new entries. Log entries written shortly before the delete operation might not be deleted. Entries received after the delete operation with a timestamp before the operation will be deleted.
override
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) Future<Operation<T, S>>
Provides the Operations service functionality in this service.
override
listLogEntries(ListLogEntriesRequest request) Future<ListLogEntriesResponse>
Lists log entries. Use this method to retrieve log entries that originated from a project/folder/organization/billing account. For ways to export log entries, see Exporting Logs.
override
listLogs(ListLogsRequest request) Future<ListLogsResponse>
Lists the logs in projects, organizations, folders, or billing accounts. Only logs that have entries are listed.
override
listMonitoredResourceDescriptors(ListMonitoredResourceDescriptorsRequest request) Future<ListMonitoredResourceDescriptorsResponse>
Lists the descriptors for monitored resource types used by Logging.
override
listOperations(ListOperationsRequest request) Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeLogEntries(WriteLogEntriesRequest request) Future<WriteLogEntriesResponse>
Writes log entries to Logging. This API method is the only way to send log entries to Logging. This method is used, directly or indirectly, by the Logging agent (fluentd) and all logging libraries configured to use Logging. A single request may contain log entries for a maximum of 1000 different resources (projects, organizations, billing accounts or folders)
override

Operators

operator ==(Object other) bool
The equality operator.
inherited