listLogEntries method

  1. @override
Future<ListLogEntriesResponse> listLogEntries(
  1. ListLogEntriesRequest request
)
override

Lists log entries. Use this method to retrieve log entries that originated from a project/folder/organization/billing account. For ways to export log entries, see Exporting Logs.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<ListLogEntriesResponse> listLogEntries(
  ListLogEntriesRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listLogEntries case final listLogEntries?) {
    return listLogEntries(request);
  }
  throw UnsupportedError('listLogEntries');
}