listLogs method

  1. @override
Future<ListLogsResponse> listLogs(
  1. ListLogsRequest request
)
override

Lists the logs in projects, organizations, folders, or billing accounts. Only logs that have entries are listed.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<ListLogsResponse> listLogs(ListLogsRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listLogs case final listLogs?) {
    return listLogs(request);
  }
  throw UnsupportedError('listLogs');
}