createBucketAsync method

  1. @override
Future<Operation<LogBucket, BucketMetadata>> createBucketAsync(
  1. CreateBucketRequest request
)
override

Creates a log bucket asynchronously that can be used to store log entries.

After a bucket has been created, the bucket's location cannot be changed.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Returns an Operation representing the status of the long-running operation.

When complete, Operation.done will be true. If successful, Operation.responseAsMessage will contain the operation's result.

Implementation

@override
Future<Operation<LogBucket, BucketMetadata>> createBucketAsync(
  CreateBucketRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createBucketAsync case final createBucketAsync?) {
    return createBucketAsync(request);
  }
  throw UnsupportedError('createBucketAsync');
}