deleteLog method
Deletes all the log entries in a log for the _Default Log Bucket. The log reappears if it receives new entries. Log entries written shortly before the delete operation might not be deleted. Entries received after the delete operation with a timestamp before the operation will be deleted.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<void> deleteLog(DeleteLogRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_deleteLog case final deleteLog?) {
return deleteLog(request);
}
throw UnsupportedError('deleteLog');
}