writeLogEntries method
Writes log entries to Logging. This API method is the only way to send log entries to Logging. This method is used, directly or indirectly, by the Logging agent (fluentd) and all logging libraries configured to use Logging. A single request may contain log entries for a maximum of 1000 different resources (projects, organizations, billing accounts or folders)
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<WriteLogEntriesResponse> writeLogEntries(
WriteLogEntriesRequest request,
) async {
if (isClosed) throw StateError('Service is closed');
if (_writeLogEntries case final writeLogEntries?) {
return writeLogEntries(request);
}
throw UnsupportedError('writeLogEntries');
}